<?php
$eid_cfg = array(
    'UserID'        =>  '',     // The user id from the registration process at the scheme operator
    'PIN'           =>  '',     // PIN

    'System'        => 'test',   // Set to 'test' for test environment, empty for production
    'Logfile'       => 'log.txt',// Writes transactions to this logfile, set empty for no log

    // Defaults for EID_Initiate, for details, see EID_Initiate description
    'ReturnUrl'       => 'https://'.$_SERVER['HTTP_HOST'].dirname($_SERVER['REQUEST_URI']).'/rsp.php',
    'ConfirmationUrl' => 'https://'.$_SERVER['HTTP_HOST'].dirname($_SERVER['REQUEST_URI']).'/confirm.php'
);

?>
