<?php
/* 
 * Sample response check for EID
 */
include_once('eid_functions.inc.php');

session_start();
echo "We may already have received status in confirmation message, but for testing purposes, we poll it to have a complete testing scenario:\n\n";
$ret = EID_Status($_SESSION['eidReq']);
if ($ret['ResponseMessage']) die($ret['ResponseMessage']);
echo "EID Status of verification is: ";
print_r($ret['VerificationDetails']);
?>
