<?
/* 
 * Sample confirmation processing for EID
 */
include("eid_functions.inc.php");

if (!isset($HTTP_RAW_POST_DATA)) $HTTP_RAW_POST_DATA = file_get_contents('php://input');
EID_PutLog("Bank server replied with:\n".utf8_decode($HTTP_RAW_POST_DATA));
$ret=EID_ParseReply($HTTP_RAW_POST_DATA);
echo ($conf=EID_Confirmation($ret));
if ($ret['ResponseMessage']) EID_PutLog('Error: '.$ret['ResponseMessage']);
//EID_PutLog('EID Status of verification is: '.print_r($ret['VerificationDetails'], true));
EID_PutLog('EID Status of verification is: '.print_r($ret, true));
EID_PutLog('Sending confirmation: '.$conf);
?>
